import { navbarButtonGroup } from '../config/config.js'

// 获取产品活动类型 (拼团 活动价 限时特价)
export function generateActivityType(productData) {
    const { collageStatus = 0, activeStatus = 0, discountStatus = 0 } = productData
    // 拼团价
    if (collageStatus > 0) {
        return 'group' // 拼团价
    }
    // 限时活动
    else if (discountStatus > 0) {
        return 'time-limit'
    }
    // 普通活动价
    else if (activeStatus > 0) {
        return 'activity'
    }
    // 普通商品
    return 'normal' // 普通价
}

// 获取产品价格类型
export function generatePriceType(productData) {
    const { couponStatus = 0, collageStatus = 0, activeStatus = 0, discountStatus = 0, couponId } = productData
    // 拼团价
    if (collageStatus > 0) {
        if (couponStatus === 1 && couponId) {
            return 'groupWithCoupon' // 拼团券后价
        } else {
            return 'group' // 拼团价
        }
    }
    // 限时活动
    else if (discountStatus > 0 || activeStatus > 0) {
        if (couponStatus === 1 && couponId) {
            return 'activityWithCoupon' // 券后价
        } else {
            return 'normal' // 限时活动价格
        }
    }
    // 无活动价
    else {
        if (couponStatus === 1 && couponId) {
            return 'normalWithCoupon' // 普通券后价
        } else {
            return 'normal' // 普通价
        }
    }
}

export function generateNavbarButtonText(productData) {
    const { priceType } = productData
    const navbarButton = navbarButtonGroup[priceType]
    // 拼团券后价购买
    if (priceType === 'groupWithCoupon') {
        navbarButton.left[1] = `￥${productData.normalCouponPrice.toFixed(2)}`
        navbarButton.right[1] = `￥${productData.couponPrice.toFixed(2)}`
    }
    // 拼团价购买
    else if (priceType === 'group') {
        navbarButton.left[1] = `￥${productData.normalPrice.toFixed(2)}`
        navbarButton.right[1] = `￥${productData.price.toFixed(2)}`
    }
    // 活动价券后价购买（限时特价|普通活动）
    else if (priceType === 'activityWithCoupon') {
        navbarButton.right[1] = `￥${productData.couponPrice.toFixed(2)}`
    }
    // 普通价券后价购买
    else if (priceType === 'normalWithCoupon') {
        navbarButton.right[1] = `￥${productData.couponPrice.toFixed(2)}`
    } else {
        navbarButton.right[1] = ''
    }
    return navbarButton
}
